@@ -1,6 +1,6 @@
 // This module implements the portability layer for the Qt port of Scintilla.
 //
-// Copyright (c) 2008 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -24,11 +24,6 @@
 // http://trolltech.com/products/qt/licenses/licensing/licensingoverview
 // or contact the sales department at sales@riverbankcomputing.com.
 // 
-// This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-// INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-// granted herein.
-// 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
@@ -214,9 +209,9 @@ private:
             int len, ColourAllocated fore);
     QFontMetrics metrics(Font &font_);
     QString convertText(const char *s, int len);
-    static QRgb convertQRgb(const ColourAllocated &col, unsigned alpha);
     static QColor convertQColor(const ColourAllocated &col,
-            unsigned alpha = 0xff);
+            unsigned alpha = 255);
+    static QRgb convertQRgb(const ColourAllocated &col, unsigned alpha);
 
     bool unicodeMode;
     QPaintDevice *pd;
@@ -526,11 +521,11 @@ void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len,
 
     // The position for each byte of a character is the offset from the start
     // where the following character should be drawn.
-    int i_byte = 0;
+    int i_byte = 0, width = 0;
 
     for (int i_char = 0; i_char < qs.length(); ++i_char)
     {
-        int width = fm.width(qs, i_char + 1);
+        width += fm.width(qs.at(i_char));
 
         if (unicodeMode)
         {
@@ -633,15 +628,19 @@ QRgb SurfaceImpl::convertQRgb(const ColourAllocated &col, unsigned alpha)
     unsigned g = (c >> 8) & 0xff;
     unsigned b = (c >> 16) & 0xff;
 
-    QRgb rgba = (alpha << 24) | (r << 16) | (g << 8) | b;
-
-    return rgba;
+    return qRgba(r, g, b, alpha);
 }
 
-// Convert a Scintilla colour, and optional alpha component, to a Qt QColor.
+// Convert a Scintilla colour, and alpha component, to a Qt QColor.
 QColor SurfaceImpl::convertQColor(const ColourAllocated &col, unsigned alpha)
 {
-    return QColor(convertQRgb(col, alpha));
+    long c = col.AsLong();
+
+    unsigned r = c & 0xff;
+    unsigned g = (c >> 8) & 0xff;
+    unsigned b = (c >> 16) & 0xff;
+
+    return QColor(r, g, b, alpha);
 }
 
 
