@@ -1,7 +1,7 @@
 // This module defines the "official" high-level API of the Qt port of
 // Scintilla.
 //
-// Copyright (c) 2008 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -25,11 +25,6 @@
 // http://trolltech.com/products/qt/licenses/licensing/licensingoverview
 // or contact the sales department at sales@riverbankcomputing.com.
 // 
-// This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-// INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-// granted herein.
-// 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
@@ -470,6 +465,12 @@ public:
     //! is no current lexer then true is returned.
     bool caseSensitive() const;
 
+    //! Clear all current folds, i.e. ensure that all lines are displayed
+    //! unfolded.
+    //!
+    //! \sa setFolding()
+    void clearFolds();
+
     //! Clear all registered images.
     //!
     //! \sa registerImage()
@@ -713,8 +714,8 @@ public:
     //! marker number is returned or -1 if the marker number was already
     //! allocated or too many markers have been defined.
     //!
-    //! Markers are small geometric symbols and character used, for example, to
-    //! indicate the current line or, in debuggers, to indicate breakpoints.
+    //! Markers are small geometric symbols and characters used, for example,
+    //! to indicate the current line or, in debuggers, to indicate breakpoints.
     //! If a margin has a width of 0 then its markers are not drawn, but their
     //! background colours affect the background colour of the corresponding
     //! line of text.
@@ -1566,6 +1567,8 @@ private slots:
 private:
     typedef QByteArray ScintillaString;
 
+    void detachLexer();
+
     enum IndentState {
         isNone,
         isKeywordStart,
